@@ -9,20 +9,19 @@
 #include <array>
 #include <limits>
 
-#include "base/allocator/buildflags.h"
 #include "base/allocator/partition_allocator/address_pool_manager_types.h"
 #include "base/allocator/partition_allocator/page_allocator_constants.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/bits.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/compiler_specific.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/component_export.h"
+#include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
 #include "base/allocator/partition_allocator/partition_alloc_forward.h"
 #include "base/allocator/partition_allocator/partition_alloc_notreached.h"
 #include "base/allocator/partition_allocator/tagging.h"
-#include "base/base_export.h"
-#include "base/compiler_specific.h"
 #include "build/build_config.h"
-#include "build/buildflag.h"
 
 // The feature is not applicable to 32-bit address space.
 #if defined(PA_HAS_64_BITS_POINTERS)
@@ -32,37 +31,36 @@ namespace partition_alloc {
 namespace internal {
 
 // Reserves address space for PartitionAllocator.
-class BASE_EXPORT PartitionAddressSpace {
+class PA_COMPONENT_EXPORT(PARTITION_ALLOC) PartitionAddressSpace {
  public:
   // BRP stands for BackupRefPtr. GigaCage is split into pools, one which
   // supports BackupRefPtr and one that doesn't.
-  static ALWAYS_INLINE internal::pool_handle GetRegularPool() {
+  static PA_ALWAYS_INLINE internal::pool_handle GetRegularPool() {
     return setup_.regular_pool_;
   }
 
 #if defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
-  static ALWAYS_INLINE uintptr_t RegularPoolBaseMask() {
+  static PA_ALWAYS_INLINE uintptr_t RegularPoolBaseMask() {
     return setup_.regular_pool_base_mask_;
   }
 #else
-  static ALWAYS_INLINE constexpr uintptr_t RegularPoolBaseMask() {
+  static PA_ALWAYS_INLINE constexpr uintptr_t RegularPoolBaseMask() {
     return kRegularPoolBaseMask;
   }
 #endif
 
-  static ALWAYS_INLINE internal::pool_handle GetBRPPool() {
+  static PA_ALWAYS_INLINE internal::pool_handle GetBRPPool() {
     return setup_.brp_pool_;
   }
 
   // The Configurable Pool can be created inside an existing mapping and so will
   // be located outside PartitionAlloc's GigaCage.
-  static ALWAYS_INLINE internal::pool_handle GetConfigurablePool() {
+  static PA_ALWAYS_INLINE internal::pool_handle GetConfigurablePool() {
     return setup_.configurable_pool_;
   }
 
-  static ALWAYS_INLINE std::pair<pool_handle, uintptr_t> GetPoolAndOffset(
+  static PA_ALWAYS_INLINE std::pair<pool_handle, uintptr_t> GetPoolAndOffset(
       uintptr_t address) {
-    address = ::partition_alloc::internal::UnmaskPtr(address);
     // When USE_BACKUP_REF_PTR is off, BRP pool isn't used.
 #if !BUILDFLAG(USE_BACKUP_REF_PTR)
     PA_DCHECK(!IsInBRPPool(address));
@@ -85,10 +83,10 @@ class BASE_EXPORT PartitionAddressSpace {
     }
     return std::make_pair(pool, address - base);
   }
-  static ALWAYS_INLINE constexpr size_t ConfigurablePoolMaxSize() {
+  static PA_ALWAYS_INLINE constexpr size_t ConfigurablePoolMaxSize() {
     return kConfigurablePoolMaxSize;
   }
-  static ALWAYS_INLINE constexpr size_t ConfigurablePoolMinSize() {
+  static PA_ALWAYS_INLINE constexpr size_t ConfigurablePoolMinSize() {
     return kConfigurablePoolMinSize;
   }
 
@@ -103,7 +101,7 @@ class BASE_EXPORT PartitionAddressSpace {
   static void UninitForTesting();
   static void UninitConfigurablePoolForTesting();
 
-  static ALWAYS_INLINE bool IsInitialized() {
+  static PA_ALWAYS_INLINE bool IsInitialized() {
     // Either neither or both regular and BRP pool are initialized. The
     // configurable pool is initialized separately.
     if (setup_.regular_pool_) {
@@ -115,13 +113,13 @@ class BASE_EXPORT PartitionAddressSpace {
     return false;
   }
 
-  static ALWAYS_INLINE bool IsConfigurablePoolInitialized() {
+  static PA_ALWAYS_INLINE bool IsConfigurablePoolInitialized() {
     return setup_.configurable_pool_base_address_ !=
            kUninitializedPoolBaseAddress;
   }
 
   // Returns false for nullptr.
-  static ALWAYS_INLINE bool IsInRegularPool(uintptr_t address) {
+  static PA_ALWAYS_INLINE bool IsInRegularPool(uintptr_t address) {
 #if defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
     const uintptr_t regular_pool_base_mask = setup_.regular_pool_base_mask_;
 #else
@@ -131,12 +129,12 @@ class BASE_EXPORT PartitionAddressSpace {
            setup_.regular_pool_base_address_;
   }
 
-  static ALWAYS_INLINE uintptr_t RegularPoolBase() {
+  static PA_ALWAYS_INLINE uintptr_t RegularPoolBase() {
     return setup_.regular_pool_base_address_;
   }
 
   // Returns false for nullptr.
-  static ALWAYS_INLINE bool IsInBRPPool(uintptr_t address) {
+  static PA_ALWAYS_INLINE bool IsInBRPPool(uintptr_t address) {
 #if defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
     const uintptr_t brp_pool_base_mask = setup_.brp_pool_base_mask_;
 #else
@@ -145,19 +143,18 @@ class BASE_EXPORT PartitionAddressSpace {
     return (address & brp_pool_base_mask) == setup_.brp_pool_base_address_;
   }
   // Returns false for nullptr.
-  static ALWAYS_INLINE bool IsInConfigurablePool(uintptr_t address) {
+  static PA_ALWAYS_INLINE bool IsInConfigurablePool(uintptr_t address) {
     return (address & setup_.configurable_pool_base_mask_) ==
            setup_.configurable_pool_base_address_;
   }
 
-  static ALWAYS_INLINE uintptr_t ConfigurablePoolBase() {
+  static PA_ALWAYS_INLINE uintptr_t ConfigurablePoolBase() {
     return setup_.configurable_pool_base_address_;
   }
 
-  static ALWAYS_INLINE uintptr_t OffsetInBRPPool(uintptr_t address) {
+  static PA_ALWAYS_INLINE uintptr_t OffsetInBRPPool(uintptr_t address) {
     PA_DCHECK(IsInBRPPool(address));
-    return ::partition_alloc::internal::UnmaskPtr(address) -
-           setup_.brp_pool_base_address_;
+    return address - setup_.brp_pool_base_address_;
   }
 
   // PartitionAddressSpace is static_only class.
@@ -168,14 +165,16 @@ class BASE_EXPORT PartitionAddressSpace {
 
  private:
 #if defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
-  static ALWAYS_INLINE size_t RegularPoolSize();
-  static ALWAYS_INLINE size_t BRPPoolSize();
+  static PA_ALWAYS_INLINE size_t RegularPoolSize();
+  static PA_ALWAYS_INLINE size_t BRPPoolSize();
 #else
   // The pool sizes should be as large as maximum whenever possible.
-  constexpr static ALWAYS_INLINE size_t RegularPoolSize() {
+  constexpr static PA_ALWAYS_INLINE size_t RegularPoolSize() {
     return kRegularPoolSize;
   }
-  constexpr static ALWAYS_INLINE size_t BRPPoolSize() { return kBRPPoolSize; }
+  constexpr static PA_ALWAYS_INLINE size_t BRPPoolSize() {
+    return kBRPPoolSize;
+  }
 #endif  // defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
 
   // On 64-bit systems, GigaCage is split into disjoint pools. The BRP pool, is
@@ -201,33 +200,37 @@ class BASE_EXPORT PartitionAddressSpace {
   static constexpr size_t kBRPPoolSize = kPoolMaxSize;
   static_assert(base::bits::IsPowerOfTwo(kRegularPoolSize) &&
                 base::bits::IsPowerOfTwo(kBRPPoolSize));
-#if BUILDFLAG(IS_IOS)
-  // TODO(crbug.com/1250788): Remove the iOS special case.
-  static constexpr size_t kConfigurablePoolMaxSize = kPoolMaxSize;
-  static constexpr size_t kConfigurablePoolMinSize = kPoolMaxSize;
-#else
   static constexpr size_t kConfigurablePoolMaxSize = kPoolMaxSize;
   static constexpr size_t kConfigurablePoolMinSize = 1 * kGiB;
-#endif
   static_assert(kConfigurablePoolMinSize <= kConfigurablePoolMaxSize);
   static_assert(base::bits::IsPowerOfTwo(kConfigurablePoolMaxSize) &&
                 base::bits::IsPowerOfTwo(kConfigurablePoolMinSize));
 
+#if BUILDFLAG(IS_IOS)
+
+#if !defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
+#error iOS is only supported with a dynamically sized GigaCase.
+#endif
+
+  // We can't afford pool sizes as large as kPoolMaxSize in iOS EarlGrey tests,
+  // since the test process cannot use an extended virtual address space (see
+  // crbug.com/1250788).
+  static constexpr size_t kRegularPoolSizeForIOSTestProcess = kGiB / 4;
+  static constexpr size_t kBRPPoolSizeForIOSTestProcess = kGiB / 4;
+  static_assert(kRegularPoolSizeForIOSTestProcess < kRegularPoolSize);
+  static_assert(kBRPPoolSizeForIOSTestProcess < kBRPPoolSize);
+  static_assert(base::bits::IsPowerOfTwo(kRegularPoolSizeForIOSTestProcess) &&
+                base::bits::IsPowerOfTwo(kBRPPoolSizeForIOSTestProcess));
+#endif  // BUILDFLAG(IOS_IOS)
+
 #if !defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
   // Masks used to easy determine belonging to a pool.
-  // On Arm, the top byte of each pointer is ignored (meaning there are
-  // effectively 256 versions of each valid pointer). 4 bits are used to store
-  // tags for Arm's Memory Tagging Extension (MTE). To ensure that tagged
-  // pointers are recognized as being in the pool, mask off the top byte with
-  // kMemTagUnmask.
   static constexpr uintptr_t kRegularPoolOffsetMask =
       static_cast<uintptr_t>(kRegularPoolSize) - 1;
-  static constexpr uintptr_t kRegularPoolBaseMask =
-      ~kRegularPoolOffsetMask & kMemTagUnmask;
+  static constexpr uintptr_t kRegularPoolBaseMask = ~kRegularPoolOffsetMask;
   static constexpr uintptr_t kBRPPoolOffsetMask =
       static_cast<uintptr_t>(kBRPPoolSize) - 1;
-  static constexpr uintptr_t kBRPPoolBaseMask =
-      ~kBRPPoolOffsetMask & kMemTagUnmask;
+  static constexpr uintptr_t kBRPPoolBaseMask = ~kBRPPoolOffsetMask;
 #endif  // !defined(PA_USE_DYNAMICALLY_SIZED_GIGA_CAGE)
 
   // This must be set to such a value that IsIn*Pool() always returns false when
@@ -284,23 +287,23 @@ class BASE_EXPORT PartitionAddressSpace {
   alignas(kPartitionCachelineSize) static GigaCageSetup setup_;
 };
 
-ALWAYS_INLINE std::pair<pool_handle, uintptr_t> GetPoolAndOffset(
+PA_ALWAYS_INLINE std::pair<pool_handle, uintptr_t> GetPoolAndOffset(
     uintptr_t address) {
   return PartitionAddressSpace::GetPoolAndOffset(address);
 }
 
-ALWAYS_INLINE pool_handle GetPool(uintptr_t address) {
+PA_ALWAYS_INLINE pool_handle GetPool(uintptr_t address) {
   return std::get<0>(GetPoolAndOffset(address));
 }
 
-ALWAYS_INLINE uintptr_t OffsetInBRPPool(uintptr_t address) {
+PA_ALWAYS_INLINE uintptr_t OffsetInBRPPool(uintptr_t address) {
   return PartitionAddressSpace::OffsetInBRPPool(address);
 }
 
 }  // namespace internal
 
 // Returns false for nullptr.
-ALWAYS_INLINE bool IsManagedByPartitionAlloc(uintptr_t address) {
+PA_ALWAYS_INLINE bool IsManagedByPartitionAlloc(uintptr_t address) {
   // When USE_BACKUP_REF_PTR is off, BRP pool isn't used.
 #if !BUILDFLAG(USE_BACKUP_REF_PTR)
   PA_DCHECK(!internal::PartitionAddressSpace::IsInBRPPool(address));
@@ -313,48 +316,27 @@ ALWAYS_INLINE bool IsManagedByPartitionAlloc(uintptr_t address) {
 }
 
 // Returns false for nullptr.
-ALWAYS_INLINE bool IsManagedByPartitionAllocRegularPool(uintptr_t address) {
+PA_ALWAYS_INLINE bool IsManagedByPartitionAllocRegularPool(uintptr_t address) {
   return internal::PartitionAddressSpace::IsInRegularPool(address);
 }
 
 // Returns false for nullptr.
-ALWAYS_INLINE bool IsManagedByPartitionAllocBRPPool(uintptr_t address) {
+PA_ALWAYS_INLINE bool IsManagedByPartitionAllocBRPPool(uintptr_t address) {
   return internal::PartitionAddressSpace::IsInBRPPool(address);
 }
 
 // Returns false for nullptr.
-ALWAYS_INLINE bool IsManagedByPartitionAllocConfigurablePool(
+PA_ALWAYS_INLINE bool IsManagedByPartitionAllocConfigurablePool(
     uintptr_t address) {
   return internal::PartitionAddressSpace::IsInConfigurablePool(address);
 }
 
-ALWAYS_INLINE bool IsConfigurablePoolAvailable() {
+PA_ALWAYS_INLINE bool IsConfigurablePoolAvailable() {
   return internal::PartitionAddressSpace::IsConfigurablePoolInitialized();
 }
 
 }  // namespace partition_alloc
 
-namespace base {
-
-// TODO(https://crbug.com/1288247): Remove these 'using' declarations once
-// the migration to the new namespaces gets done.
-using ::partition_alloc::IsConfigurablePoolAvailable;
-using ::partition_alloc::IsManagedByPartitionAlloc;
-using ::partition_alloc::IsManagedByPartitionAllocBRPPool;
-using ::partition_alloc::IsManagedByPartitionAllocConfigurablePool;
-using ::partition_alloc::IsManagedByPartitionAllocRegularPool;
-
-namespace internal {
-
-using ::partition_alloc::internal::GetPool;
-using ::partition_alloc::internal::GetPoolAndOffset;
-using ::partition_alloc::internal::OffsetInBRPPool;
-using ::partition_alloc::internal::PartitionAddressSpace;
-
-}  // namespace internal
-
-}  // namespace base
-
 #endif  // defined(PA_HAS_64_BITS_POINTERS)
 
 #endif  // BASE_ALLOCATOR_PARTITION_ALLOCATOR_PARTITION_ADDRESS_SPACE_H_
