@@ -9,13 +9,13 @@
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_lock.h"
 
-namespace base {
+namespace partition_alloc {
 
 namespace {
 
-internal::PartitionLock g_hook_lock;
+internal::Lock g_hook_lock;
 
-internal::PartitionLock& GetHooksLock() {
+internal::Lock& GetHooksLock() {
   return g_hook_lock;
 }
 
@@ -35,7 +35,7 @@ std::atomic<PartitionAllocHooks::ReallocOverrideHook*>
 
 void PartitionAllocHooks::SetObserverHooks(AllocationObserverHook* alloc_hook,
                                            FreeObserverHook* free_hook) {
-  internal::PartitionAutoLock guard(GetHooksLock());
+  internal::ScopedGuard guard(GetHooksLock());
 
   // Chained hooks are not supported. Registering a non-null hook when a
   // non-null hook is already registered indicates somebody is trying to
@@ -52,7 +52,7 @@ void PartitionAllocHooks::SetObserverHooks(AllocationObserverHook* alloc_hook,
 void PartitionAllocHooks::SetOverrideHooks(AllocationOverrideHook* alloc_hook,
                                            FreeOverrideHook* free_hook,
                                            ReallocOverrideHook realloc_hook) {
-  internal::PartitionAutoLock guard(GetHooksLock());
+  internal::ScopedGuard guard(GetHooksLock());
 
   PA_CHECK((!allocation_override_hook_ && !free_override_hook_ &&
             !realloc_override_hook_) ||
@@ -75,7 +75,7 @@ void PartitionAllocHooks::AllocationObserverHookIfEnabled(
 
 bool PartitionAllocHooks::AllocationOverrideHookIfEnabled(
     void** out,
-    int flags,
+    unsigned int flags,
     size_t size,
     const char* type_name) {
   if (auto* hook = allocation_override_hook_.load(std::memory_order_relaxed))
@@ -118,4 +118,4 @@ bool PartitionAllocHooks::ReallocOverrideHookIfEnabled(size_t* out,
   return false;
 }
 
-}  // namespace base
+}  // namespace partition_alloc
