@@ -10,11 +10,15 @@
 #include <limits>
 #include <utility>
 
-#include "base/allocator/buildflags.h"
 #include "base/allocator/partition_allocator/address_pool_manager.h"
 #include "base/allocator/partition_allocator/address_pool_manager_types.h"
 #include "base/allocator/partition_allocator/partition_address_space.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/bits.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/compiler_specific.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/component_export.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/debug/debugging_buildflags.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/thread_annotations.h"
+#include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
 #include "base/allocator/partition_allocator/partition_alloc_forward.h"
@@ -24,10 +28,6 @@
 #include "base/allocator/partition_allocator/reservation_offset_table.h"
 #include "base/allocator/partition_allocator/starscan/state_bitmap.h"
 #include "base/allocator/partition_allocator/tagging.h"
-#include "base/base_export.h"
-#include "base/compiler_specific.h"
-#include "base/dcheck_is_on.h"
-#include "base/thread_annotations.h"
 #include "build/build_config.h"
 
 #if BUILDFLAG(PUT_REF_COUNT_IN_PREVIOUS_SLOT)
@@ -45,8 +45,8 @@ struct PartitionSuperPageExtentEntry {
   uint16_t number_of_consecutive_super_pages;
   uint16_t number_of_nonempty_slot_spans;
 
-  ALWAYS_INLINE void IncrementNumberOfNonemptySlotSpans();
-  ALWAYS_INLINE void DecrementNumberOfNonemptySlotSpans();
+  PA_ALWAYS_INLINE void IncrementNumberOfNonemptySlotSpans();
+  PA_ALWAYS_INLINE void DecrementNumberOfNonemptySlotSpans();
 };
 static_assert(
     sizeof(PartitionSuperPageExtentEntry<ThreadSafe>) <= kPageMetadataSize,
@@ -64,7 +64,7 @@ static_assert(
 // CAUTION! |extent| must point to the extent of the first super page in the
 // range of consecutive super pages.
 template <bool thread_safe>
-ALWAYS_INLINE uintptr_t SuperPagesBeginFromExtent(
+PA_ALWAYS_INLINE uintptr_t SuperPagesBeginFromExtent(
     const PartitionSuperPageExtentEntry<thread_safe>* extent) {
   PA_DCHECK(0 < extent->number_of_consecutive_super_pages);
   uintptr_t extent_as_uintptr = reinterpret_cast<uintptr_t>(extent);
@@ -78,7 +78,7 @@ ALWAYS_INLINE uintptr_t SuperPagesBeginFromExtent(
 // CAUTION! |extent| must point to the extent of the first super page in the
 // range of consecutive super pages.
 template <bool thread_safe>
-ALWAYS_INLINE uintptr_t SuperPagesEndFromExtent(
+PA_ALWAYS_INLINE uintptr_t SuperPagesEndFromExtent(
     const PartitionSuperPageExtentEntry<thread_safe>* extent) {
   return SuperPagesBeginFromExtent(extent) +
          (extent->number_of_consecutive_super_pages * kSuperPageSize);
@@ -173,19 +173,21 @@ struct SlotSpanMetadata {
   // in PartitionPage which has 2B worth of fields and must fit in 32B.
 
  public:
+  PA_COMPONENT_EXPORT(PARTITION_ALLOC)
   explicit SlotSpanMetadata(PartitionBucket<thread_safe>* bucket);
 
   // Public API
   // Note the matching Alloc() functions are in PartitionPage.
-  BASE_EXPORT NOINLINE void FreeSlowPath(size_t number_of_freed);
-  ALWAYS_INLINE PartitionFreelistEntry* PopForAlloc(size_t size);
-  ALWAYS_INLINE void Free(uintptr_t ptr);
+  PA_COMPONENT_EXPORT(PARTITION_ALLOC)
+  PA_NOINLINE void FreeSlowPath(size_t number_of_freed);
+  PA_ALWAYS_INLINE PartitionFreelistEntry* PopForAlloc(size_t size);
+  PA_ALWAYS_INLINE void Free(uintptr_t ptr);
   // Appends the passed freelist to the slot-span's freelist. Please note that
   // the function doesn't increment the tags of the passed freelist entries,
   // since FreeNoHooks() did it already.
-  ALWAYS_INLINE void AppendFreeList(PartitionFreelistEntry* head,
-                                    PartitionFreelistEntry* tail,
-                                    size_t number_of_freed);
+  PA_ALWAYS_INLINE void AppendFreeList(PartitionFreelistEntry* head,
+                                       PartitionFreelistEntry* tail,
+                                       size_t number_of_freed);
 
   void Decommit(PartitionRoot<thread_safe>* root);
   void DecommitIfPossible(PartitionRoot<thread_safe>* root);
@@ -200,38 +202,39 @@ struct SlotSpanMetadata {
   // |slot_span| pointer may be the result of an offset calculation and
   // therefore cannot be trusted. The objective of these functions is to
   // sanitize this input.
-  ALWAYS_INLINE static uintptr_t ToSlotSpanStart(
+  PA_ALWAYS_INLINE static uintptr_t ToSlotSpanStart(
       const SlotSpanMetadata* slot_span);
-  ALWAYS_INLINE static SlotSpanMetadata* FromAddr(uintptr_t address);
-  ALWAYS_INLINE static SlotSpanMetadata* FromSlotStart(uintptr_t slot_start);
-  ALWAYS_INLINE static SlotSpanMetadata* FromObject(void* object);
-  ALWAYS_INLINE static SlotSpanMetadata* FromObjectInnerAddr(uintptr_t address);
-  ALWAYS_INLINE static SlotSpanMetadata* FromObjectInnerPtr(void* ptr);
+  PA_ALWAYS_INLINE static SlotSpanMetadata* FromAddr(uintptr_t address);
+  PA_ALWAYS_INLINE static SlotSpanMetadata* FromSlotStart(uintptr_t slot_start);
+  PA_ALWAYS_INLINE static SlotSpanMetadata* FromObject(void* object);
+  PA_ALWAYS_INLINE static SlotSpanMetadata* FromObjectInnerAddr(
+      uintptr_t address);
+  PA_ALWAYS_INLINE static SlotSpanMetadata* FromObjectInnerPtr(void* ptr);
 
-  ALWAYS_INLINE PartitionSuperPageExtentEntry<thread_safe>* ToSuperPageExtent()
-      const;
+  PA_ALWAYS_INLINE PartitionSuperPageExtentEntry<thread_safe>*
+  ToSuperPageExtent() const;
 
   // Checks if it is feasible to store raw_size.
-  ALWAYS_INLINE bool CanStoreRawSize() const { return can_store_raw_size_; }
+  PA_ALWAYS_INLINE bool CanStoreRawSize() const { return can_store_raw_size_; }
   // The caller is responsible for ensuring that raw_size can be stored before
   // calling Set/GetRawSize.
-  ALWAYS_INLINE void SetRawSize(size_t raw_size);
-  ALWAYS_INLINE size_t GetRawSize() const;
+  PA_ALWAYS_INLINE void SetRawSize(size_t raw_size);
+  PA_ALWAYS_INLINE size_t GetRawSize() const;
 
-  ALWAYS_INLINE PartitionFreelistEntry* get_freelist_head() const {
+  PA_ALWAYS_INLINE PartitionFreelistEntry* get_freelist_head() const {
     return freelist_head;
   }
-  ALWAYS_INLINE void SetFreelistHead(PartitionFreelistEntry* new_head);
+  PA_ALWAYS_INLINE void SetFreelistHead(PartitionFreelistEntry* new_head);
 
   // Returns size of the region used within a slot. The used region comprises
   // of actual allocated data, extras and possibly empty space in the middle.
-  ALWAYS_INLINE size_t GetUtilizedSlotSize() const {
+  PA_ALWAYS_INLINE size_t GetUtilizedSlotSize() const {
     // The returned size can be:
     // - The slot size for small buckets.
     // - Exact size needed to satisfy allocation (incl. extras), for large
     //   buckets and direct-mapped allocations (see also the comment in
     //   CanStoreRawSize() for more info).
-    if (LIKELY(!CanStoreRawSize())) {
+    if (PA_LIKELY(!CanStoreRawSize())) {
       return bucket->slot_size;
     }
     return GetRawSize();
@@ -239,7 +242,7 @@ struct SlotSpanMetadata {
 
   // This includes padding due to rounding done at allocation; we don't know the
   // requested size at deallocation, so we use this in both places.
-  ALWAYS_INLINE size_t GetSlotSizeForBookkeeping() const {
+  PA_ALWAYS_INLINE size_t GetSlotSizeForBookkeeping() const {
     // This could be more precise for allocations where CanStoreRawSize()
     // returns true (large allocations). However this is called for *every*
     // allocation, so we don't want an extra branch there.
@@ -250,7 +253,8 @@ struct SlotSpanMetadata {
   // requested size. If higher, the overage won't exceed what's actually usable
   // by the app without a risk of running out of an allocated region or into
   // PartitionAlloc's internal data (like extras).
-  ALWAYS_INLINE size_t GetUsableSize(PartitionRoot<thread_safe>* root) const {
+  PA_ALWAYS_INLINE size_t
+  GetUsableSize(PartitionRoot<thread_safe>* root) const {
     // The returned size can be:
     // - The slot size minus extras, for small buckets. This could be more than
     //   requested size.
@@ -261,7 +265,7 @@ struct SlotSpanMetadata {
   }
 
   // Returns the total size of the slots that are currently provisioned.
-  ALWAYS_INLINE size_t GetProvisionedSize() const {
+  PA_ALWAYS_INLINE size_t GetProvisionedSize() const {
     size_t num_provisioned_slots =
         bucket->get_slots_per_span() - num_unprovisioned_slots;
     size_t provisioned_size = num_provisioned_slots * bucket->slot_size;
@@ -269,19 +273,29 @@ struct SlotSpanMetadata {
     return provisioned_size;
   }
 
-  ALWAYS_INLINE void Reset();
+  // Return the number of entries in the freelist.
+  size_t GetFreelistLength() const {
+    size_t num_provisioned_slots =
+        bucket->get_slots_per_span() - num_unprovisioned_slots;
+    return num_provisioned_slots - num_allocated_slots;
+  }
+
+  PA_ALWAYS_INLINE void Reset();
 
   // TODO(ajwong): Can this be made private?  https://crbug.com/787153
-  BASE_EXPORT static SlotSpanMetadata* get_sentinel_slot_span();
+  PA_COMPONENT_EXPORT(PARTITION_ALLOC)
+  static SlotSpanMetadata* get_sentinel_slot_span();
 
   // Slot span state getters.
-  ALWAYS_INLINE bool is_active() const;
-  ALWAYS_INLINE bool is_full() const;
-  ALWAYS_INLINE bool is_empty() const;
-  ALWAYS_INLINE bool is_decommitted() const;
-  ALWAYS_INLINE bool in_empty_cache() const { return in_empty_cache_; }
-  ALWAYS_INLINE bool freelist_is_sorted() const { return freelist_is_sorted_; }
-  ALWAYS_INLINE void set_freelist_sorted() { freelist_is_sorted_ = true; }
+  PA_ALWAYS_INLINE bool is_active() const;
+  PA_ALWAYS_INLINE bool is_full() const;
+  PA_ALWAYS_INLINE bool is_empty() const;
+  PA_ALWAYS_INLINE bool is_decommitted() const;
+  PA_ALWAYS_INLINE bool in_empty_cache() const { return in_empty_cache_; }
+  PA_ALWAYS_INLINE bool freelist_is_sorted() const {
+    return freelist_is_sorted_;
+  }
+  PA_ALWAYS_INLINE void set_freelist_sorted() { freelist_is_sorted_ = true; }
 
  private:
   // sentinel_slot_span_ is used as a sentinel to indicate that there is no slot
@@ -290,7 +304,7 @@ struct SlotSpanMetadata {
   //
   // Note, this declaration is kept in the header as opposed to an anonymous
   // namespace so the getter can be fully inlined.
-  static SlotSpanMetadata sentinel_slot_span_;
+  static inline SlotSpanMetadata sentinel_slot_span_;
   // For the sentinel.
   constexpr SlotSpanMetadata() noexcept
       : marked_full(0),
@@ -367,7 +381,7 @@ struct PartitionPage {
   bool has_valid_span_after_this : 1;
   uint8_t unused;
 
-  ALWAYS_INLINE static PartitionPage* FromAddr(uintptr_t address);
+  PA_ALWAYS_INLINE static PartitionPage* FromAddr(uintptr_t address);
 };
 #pragma pack(pop)
 static_assert(sizeof(PartitionPage<ThreadSafe>) == kPageMetadataSize,
@@ -381,7 +395,7 @@ static_assert(offsetof(PartitionPage<ThreadSafe>, subsequent_page_metadata) ==
               "");
 
 template <bool thread_safe>
-ALWAYS_INLINE PartitionPage<thread_safe>* PartitionSuperPageToMetadataArea(
+PA_ALWAYS_INLINE PartitionPage<thread_safe>* PartitionSuperPageToMetadataArea(
     uintptr_t super_page) {
   // This can't be just any super page, but it has to be the first super page of
   // the reservation, as we assume here that the metadata is near its beginning.
@@ -394,7 +408,7 @@ ALWAYS_INLINE PartitionPage<thread_safe>* PartitionSuperPageToMetadataArea(
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE PartitionSuperPageExtentEntry<thread_safe>*
+PA_ALWAYS_INLINE PartitionSuperPageExtentEntry<thread_safe>*
 PartitionSuperPageToExtent(uintptr_t super_page) {
   // The very first entry of the metadata is the super page extent entry.
   return reinterpret_cast<PartitionSuperPageExtentEntry<thread_safe>*>(
@@ -404,61 +418,62 @@ PartitionSuperPageToExtent(uintptr_t super_page) {
 // Size that should be reserved for state bitmap (if present) inside a super
 // page. Elements of a super page are partition-page-aligned, hence the returned
 // size is a multiple of partition page size.
-PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR ALWAYS_INLINE size_t
+PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR PA_ALWAYS_INLINE size_t
 ReservedStateBitmapSize() {
   return base::bits::AlignUp(sizeof(AllocationStateMap), PartitionPageSize());
 }
 
 // Size that should be committed for state bitmap (if present) inside a super
 // page. It is a multiple of system page size.
-PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR ALWAYS_INLINE size_t
+PAGE_ALLOCATOR_CONSTANTS_DECLARE_CONSTEXPR PA_ALWAYS_INLINE size_t
 CommittedStateBitmapSize() {
   return base::bits::AlignUp(sizeof(AllocationStateMap), SystemPageSize());
 }
 
 // Returns the address/pointer to the state bitmap in the super page. It's the
 // caller's responsibility to ensure that the bitmaps even exist.
-ALWAYS_INLINE uintptr_t SuperPageStateBitmapAddr(uintptr_t super_page) {
+PA_ALWAYS_INLINE uintptr_t SuperPageStateBitmapAddr(uintptr_t super_page) {
   PA_DCHECK(!(super_page % kSuperPageAlignment));
   return super_page + PartitionPageSize() +
          (IsManagedByNormalBuckets(super_page) ? ReservedTagBitmapSize() : 0);
 }
-ALWAYS_INLINE AllocationStateMap* SuperPageStateBitmap(uintptr_t super_page) {
+PA_ALWAYS_INLINE AllocationStateMap* SuperPageStateBitmap(
+    uintptr_t super_page) {
   return reinterpret_cast<AllocationStateMap*>(
       SuperPageStateBitmapAddr(super_page));
 }
 
 // Returns the address of the tag bitmap of the `super_page`. Caller must ensure
 // that bitmap exists.
-ALWAYS_INLINE uintptr_t SuperPageTagBitmapAddr(uintptr_t super_page) {
+PA_ALWAYS_INLINE uintptr_t SuperPageTagBitmapAddr(uintptr_t super_page) {
   PA_DCHECK(IsReservationStart(super_page));
   // Skip over the guard pages / metadata.
   return super_page + PartitionPageSize();
 }
 
-ALWAYS_INLINE uintptr_t SuperPagePayloadBegin(uintptr_t super_page,
-                                              bool with_quarantine) {
+PA_ALWAYS_INLINE uintptr_t SuperPagePayloadBegin(uintptr_t super_page,
+                                                 bool with_quarantine) {
   PA_DCHECK(!(super_page % kSuperPageAlignment));
   return super_page + PartitionPageSize() +
          (IsManagedByNormalBuckets(super_page) ? ReservedTagBitmapSize() : 0) +
          (with_quarantine ? ReservedStateBitmapSize() : 0);
 }
 
-ALWAYS_INLINE uintptr_t SuperPagePayloadEnd(uintptr_t super_page) {
+PA_ALWAYS_INLINE uintptr_t SuperPagePayloadEnd(uintptr_t super_page) {
   PA_DCHECK(!(super_page % kSuperPageAlignment));
   return super_page + kSuperPageSize - PartitionPageSize();
 }
 
-ALWAYS_INLINE size_t SuperPagePayloadSize(uintptr_t super_page,
-                                          bool with_quarantine) {
+PA_ALWAYS_INLINE size_t SuperPagePayloadSize(uintptr_t super_page,
+                                             bool with_quarantine) {
   return SuperPagePayloadEnd(super_page) -
          SuperPagePayloadBegin(super_page, with_quarantine);
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void PartitionSuperPageExtentEntry<
+PA_ALWAYS_INLINE void PartitionSuperPageExtentEntry<
     thread_safe>::IncrementNumberOfNonemptySlotSpans() {
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   uintptr_t super_page = base::bits::AlignDown(
       reinterpret_cast<uintptr_t>(this), kSuperPageAlignment);
   PA_DCHECK((SuperPagePayloadSize(super_page, root->IsQuarantineAllowed()) /
@@ -468,14 +483,14 @@ ALWAYS_INLINE void PartitionSuperPageExtentEntry<
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void PartitionSuperPageExtentEntry<
+PA_ALWAYS_INLINE void PartitionSuperPageExtentEntry<
     thread_safe>::DecrementNumberOfNonemptySlotSpans() {
   PA_DCHECK(number_of_nonempty_slot_spans);
   --number_of_nonempty_slot_spans;
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE PartitionSuperPageExtentEntry<thread_safe>*
+PA_ALWAYS_INLINE PartitionSuperPageExtentEntry<thread_safe>*
 SlotSpanMetadata<thread_safe>::ToSuperPageExtent() const {
   uintptr_t super_page = reinterpret_cast<uintptr_t>(this) & kSuperPageBaseMask;
   return PartitionSuperPageToExtent<thread_safe>(super_page);
@@ -485,9 +500,8 @@ SlotSpanMetadata<thread_safe>::ToSuperPageExtent() const {
 // area devoted to slot spans). It doesn't check whether it's within a valid
 // slot span. It merely ensures it doesn't fall in a meta-data region that would
 // surely never contain user data.
-ALWAYS_INLINE bool IsWithinSuperPagePayload(uintptr_t address,
-                                            bool with_quarantine) {
-  address = ::partition_alloc::internal::UnmaskPtr(address);
+PA_ALWAYS_INLINE bool IsWithinSuperPagePayload(uintptr_t address,
+                                               bool with_quarantine) {
   // Quarantine can only be enabled for normal buckets in the current code.
   PA_DCHECK(!with_quarantine || IsManagedByNormalBuckets(address));
   uintptr_t super_page = address & kSuperPageBaseMask;
@@ -506,11 +520,11 @@ ALWAYS_INLINE bool IsWithinSuperPagePayload(uintptr_t address,
 // care has to be taken with direct maps that span multiple super pages. This
 // function's behavior is undefined if |ptr| lies in a subsequent super page.
 template <bool thread_safe>
-ALWAYS_INLINE PartitionPage<thread_safe>* PartitionPage<thread_safe>::FromAddr(
-    uintptr_t address) {
+PA_ALWAYS_INLINE PartitionPage<thread_safe>*
+PartitionPage<thread_safe>::FromAddr(uintptr_t address) {
   uintptr_t super_page = address & kSuperPageBaseMask;
 
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   PA_DCHECK(IsReservationStart(super_page));
   auto* extent = PartitionSuperPageToExtent<thread_safe>(super_page);
   PA_DCHECK(IsWithinSuperPagePayload(address,
@@ -534,7 +548,7 @@ ALWAYS_INLINE PartitionPage<thread_safe>* PartitionPage<thread_safe>::FromAddr(
 // pages's metadata) into a pointer to the beginning of the slot span. This
 // works on direct maps too.
 template <bool thread_safe>
-ALWAYS_INLINE uintptr_t SlotSpanMetadata<thread_safe>::ToSlotSpanStart(
+PA_ALWAYS_INLINE uintptr_t SlotSpanMetadata<thread_safe>::ToSlotSpanStart(
     const SlotSpanMetadata* slot_span) {
   uintptr_t pointer_as_uint = reinterpret_cast<uintptr_t>(slot_span);
   uintptr_t super_page_offset = (pointer_as_uint & kSuperPageOffsetMask);
@@ -564,9 +578,8 @@ ALWAYS_INLINE uintptr_t SlotSpanMetadata<thread_safe>::ToSlotSpanStart(
 // CAUTION! For direct-mapped allocation, |address| has to be within the first
 // partition page.
 template <bool thread_safe>
-ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
+PA_ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
 SlotSpanMetadata<thread_safe>::FromAddr(uintptr_t address) {
-  address = ::partition_alloc::internal::UnmaskPtr(address);
   auto* page = PartitionPage<thread_safe>::FromAddr(address);
   PA_DCHECK(page->is_valid);
   // Partition pages in the same slot span share the same SlotSpanMetadata
@@ -590,16 +603,14 @@ SlotSpanMetadata<thread_safe>::FromAddr(uintptr_t address) {
 //
 // This works on direct maps too.
 template <bool thread_safe>
-ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
+PA_ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
 SlotSpanMetadata<thread_safe>::FromSlotStart(uintptr_t slot_start) {
   auto* slot_span = FromAddr(slot_start);
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   // Checks that the pointer is a multiple of slot size.
   uintptr_t slot_span_start = ToSlotSpanStart(slot_span);
-  PA_DCHECK(!((::partition_alloc::internal::UnmaskPtr(slot_start) -
-               ::partition_alloc::internal::UnmaskPtr(slot_span_start)) %
-              slot_span->bucket->slot_size));
-#endif  // DCHECK_IS_ON()
+  PA_DCHECK(!((slot_start - slot_span_start) % slot_span->bucket->slot_size));
+#endif  // BUILDFLAG(PA_DCHECK_IS_ON)
   return slot_span;
 }
 
@@ -608,20 +619,18 @@ SlotSpanMetadata<thread_safe>::FromSlotStart(uintptr_t slot_start) {
 //
 // This works on direct maps too.
 template <bool thread_safe>
-ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
+PA_ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
 SlotSpanMetadata<thread_safe>::FromObject(void* object) {
-  uintptr_t object_addr = PartitionRoot<thread_safe>::ObjectPtr2Addr(object);
+  uintptr_t object_addr = ObjectPtr2Addr(object);
   auto* slot_span = FromAddr(object_addr);
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   // Checks that the object is exactly |extras_offset| away from a multiple of
   // slot size (i.e. from a slot start).
   uintptr_t slot_span_start = ToSlotSpanStart(slot_span);
   auto* root = PartitionRoot<thread_safe>::FromSlotSpan(slot_span);
-  PA_DCHECK((::partition_alloc::internal::UnmaskPtr(object_addr) -
-             ::partition_alloc::internal::UnmaskPtr(slot_span_start)) %
-                slot_span->bucket->slot_size ==
-            root->extras_offset);
-#endif  // DCHECK_IS_ON()
+  PA_DCHECK((object_addr - slot_span_start) % slot_span->bucket->slot_size ==
+            root->flags.extras_offset);
+#endif  // BUILDFLAG(PA_DCHECK_IS_ON)
   return slot_span;
 }
 
@@ -631,38 +640,38 @@ SlotSpanMetadata<thread_safe>::FromObject(void* object) {
 // CAUTION! For direct-mapped allocation, |address| has to be within the first
 // partition page.
 template <bool thread_safe>
-ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
+PA_ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
 SlotSpanMetadata<thread_safe>::FromObjectInnerAddr(uintptr_t address) {
   auto* slot_span = FromAddr(address);
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   // Checks that the address is within the expected object boundaries.
   uintptr_t slot_span_start = ToSlotSpanStart(slot_span);
   auto* root = PartitionRoot<thread_safe>::FromSlotSpan(slot_span);
   uintptr_t shift_from_slot_start =
       (address - slot_span_start) % slot_span->bucket->slot_size;
-  PA_DCHECK(shift_from_slot_start >= root->extras_offset);
+  PA_DCHECK(shift_from_slot_start >= root->flags.extras_offset);
   // Use <= to allow an address immediately past the object.
   PA_DCHECK(shift_from_slot_start <=
-            root->extras_offset + slot_span->GetUsableSize(root));
-#endif  // DCHECK_IS_ON()
+            root->flags.extras_offset + slot_span->GetUsableSize(root));
+#endif  // BUILDFLAG(PA_DCHECK_IS_ON)
   return slot_span;
 }
 template <bool thread_safe>
-ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
+PA_ALWAYS_INLINE SlotSpanMetadata<thread_safe>*
 SlotSpanMetadata<thread_safe>::FromObjectInnerPtr(void* ptr) {
-  return FromObjectInnerAddr(
-      PartitionRoot<thread_safe>::ObjectInnerPtr2Addr(ptr));
+  return FromObjectInnerAddr(ObjectInnerPtr2Addr(ptr));
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::SetRawSize(size_t raw_size) {
+PA_ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::SetRawSize(
+    size_t raw_size) {
   PA_DCHECK(CanStoreRawSize());
   auto* the_next_page = reinterpret_cast<PartitionPage<thread_safe>*>(this) + 1;
   the_next_page->subsequent_page_metadata.raw_size = raw_size;
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE size_t SlotSpanMetadata<thread_safe>::GetRawSize() const {
+PA_ALWAYS_INLINE size_t SlotSpanMetadata<thread_safe>::GetRawSize() const {
   PA_DCHECK(CanStoreRawSize());
   auto* the_next_page =
       reinterpret_cast<const PartitionPage<thread_safe>*>(this) + 1;
@@ -670,11 +679,16 @@ ALWAYS_INLINE size_t SlotSpanMetadata<thread_safe>::GetRawSize() const {
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::SetFreelistHead(
+PA_ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::SetFreelistHead(
     PartitionFreelistEntry* new_head) {
+#if BUILDFLAG(PA_DCHECK_IS_ON)
+  // |this| is in the metadata region, hence isn't MTE-tagged. Untag |new_head|
+  // as well.
+  uintptr_t new_head_untagged = UntagPtr(new_head);
   PA_DCHECK(!new_head ||
             (reinterpret_cast<uintptr_t>(this) & kSuperPageBaseMask) ==
-                (reinterpret_cast<uintptr_t>(new_head) & kSuperPageBaseMask));
+                (new_head_untagged & kSuperPageBaseMask));
+#endif
   freelist_head = new_head;
   // Inserted something new in the freelist, assume that it is not sorted
   // anymore.
@@ -682,7 +696,7 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::SetFreelistHead(
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE PartitionFreelistEntry*
+PA_ALWAYS_INLINE PartitionFreelistEntry*
 SlotSpanMetadata<thread_safe>::PopForAlloc(size_t size) {
   // Not using bucket->slot_size directly as the compiler doesn't know that
   // |bucket->slot_size| is the same as |size|.
@@ -696,15 +710,16 @@ SlotSpanMetadata<thread_safe>::PopForAlloc(size_t size) {
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Free(uintptr_t slot_start)
-    EXCLUSIVE_LOCKS_REQUIRED(
+PA_ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Free(uintptr_t slot_start)
+    PA_EXCLUSIVE_LOCKS_REQUIRED(
         PartitionRoot<thread_safe>::FromSlotSpan(this)->lock_) {
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   auto* root = PartitionRoot<thread_safe>::FromSlotSpan(this);
   root->lock_.AssertAcquired();
 #endif
 
-  auto* entry = reinterpret_cast<internal::PartitionFreelistEntry*>(slot_start);
+  auto* entry = static_cast<internal::PartitionFreelistEntry*>(
+      SlotStartAddr2Ptr(slot_start));
   // Catches an immediate double free.
   PA_CHECK(entry != freelist_head);
   // Look for double free one level deeper in debug.
@@ -717,7 +732,7 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Free(uintptr_t slot_start)
   --num_allocated_slots;
   // If the span is marked full, or became empty, take the slow path to update
   // internal state.
-  if (UNLIKELY(marked_full || num_allocated_slots == 0)) {
+  if (PA_UNLIKELY(marked_full || num_allocated_slots == 0)) {
     FreeSlowPath(1);
   } else {
     // All single-slot allocations must go through the slow path to
@@ -727,13 +742,13 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Free(uintptr_t slot_start)
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::AppendFreeList(
+PA_ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::AppendFreeList(
     PartitionFreelistEntry* head,
     PartitionFreelistEntry* tail,
     size_t number_of_freed)
-    EXCLUSIVE_LOCKS_REQUIRED(
+    PA_EXCLUSIVE_LOCKS_REQUIRED(
         PartitionRoot<thread_safe>::FromSlotSpan(this)->lock_) {
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   auto* root = PartitionRoot<thread_safe>::FromSlotSpan(this);
   root->lock_.AssertAcquired();
   PA_DCHECK(!tail->GetNext(bucket->slot_size));
@@ -746,11 +761,10 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::AppendFreeList(
     size_t number_of_entries = 0;
     for (auto* entry = head; entry;
          entry = entry->GetNext(bucket->slot_size), ++number_of_entries) {
-      uintptr_t unmasked_entry = ::partition_alloc::internal::UnmaskPtr(
-          reinterpret_cast<uintptr_t>(entry));
+      uintptr_t untagged_entry = UntagPtr(entry);
       // Check that all entries belong to this slot span.
-      PA_DCHECK(ToSlotSpanStart(this) <= unmasked_entry);
-      PA_DCHECK(unmasked_entry <
+      PA_DCHECK(ToSlotSpanStart(this) <= untagged_entry);
+      PA_DCHECK(untagged_entry <
                 ToSlotSpanStart(this) + bucket->get_bytes_per_span());
     }
     PA_DCHECK(number_of_entries == number_of_freed);
@@ -763,7 +777,7 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::AppendFreeList(
   num_allocated_slots -= number_of_freed;
   // If the span is marked full, or became empty, take the slow path to update
   // internal state.
-  if (UNLIKELY(marked_full || num_allocated_slots == 0)) {
+  if (PA_UNLIKELY(marked_full || num_allocated_slots == 0)) {
     FreeSlowPath(number_of_freed);
   } else {
     // All single-slot allocations must go through the slow path to
@@ -773,7 +787,7 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::AppendFreeList(
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_active() const {
+PA_ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_active() const {
   PA_DCHECK(this != get_sentinel_slot_span());
   bool ret =
       (num_allocated_slots > 0 && (freelist_head || num_unprovisioned_slots));
@@ -785,7 +799,7 @@ ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_active() const {
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_full() const {
+PA_ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_full() const {
   PA_DCHECK(this != get_sentinel_slot_span());
   bool ret = (num_allocated_slots == bucket->get_slots_per_span());
   if (ret) {
@@ -797,7 +811,7 @@ ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_full() const {
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_empty() const {
+PA_ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_empty() const {
   PA_DCHECK(this != get_sentinel_slot_span());
   bool ret = (!num_allocated_slots && freelist_head);
   if (ret) {
@@ -807,7 +821,7 @@ ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_empty() const {
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_decommitted() const {
+PA_ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_decommitted() const {
   PA_DCHECK(this != get_sentinel_slot_span());
   bool ret = (!num_allocated_slots && !freelist_head);
   if (ret) {
@@ -819,7 +833,7 @@ ALWAYS_INLINE bool SlotSpanMetadata<thread_safe>::is_decommitted() const {
 }
 
 template <bool thread_safe>
-ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Reset() {
+PA_ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Reset() {
   PA_DCHECK(is_decommitted());
 
   num_unprovisioned_slots = bucket->get_slots_per_span();
@@ -832,7 +846,7 @@ ALWAYS_INLINE void SlotSpanMetadata<thread_safe>::Reset() {
 
 // Returns the state bitmap from an address within a normal-bucket super page.
 // It's the caller's responsibility to ensure that the bitmap exists.
-ALWAYS_INLINE AllocationStateMap* StateBitmapFromAddr(uintptr_t address) {
+PA_ALWAYS_INLINE AllocationStateMap* StateBitmapFromAddr(uintptr_t address) {
   PA_DCHECK(IsManagedByNormalBuckets(address));
   uintptr_t super_page = address & kSuperPageBaseMask;
   return SuperPageStateBitmap(super_page);
@@ -844,7 +858,7 @@ template <bool thread_safe, typename Callback>
 void IterateSlotSpans(uintptr_t super_page,
                       bool with_quarantine,
                       Callback callback) {
-#if DCHECK_IS_ON()
+#if BUILDFLAG(PA_DCHECK_IS_ON)
   PA_DCHECK(!(super_page % kSuperPageAlignment));
   auto* extent_entry = PartitionSuperPageToExtent<thread_safe>(super_page);
   extent_entry->root->lock_.AssertAcquired();
@@ -886,23 +900,4 @@ void IterateSlotSpans(uintptr_t super_page,
 
 }  // namespace partition_alloc::internal
 
-namespace base::internal {
-
-// TODO(https://crbug.com/1288247): Remove these 'using' declarations once
-// the migration to the new namespaces gets done.
-using ::partition_alloc::internal::AllocationStateMap;
-using ::partition_alloc::internal::CommittedStateBitmapSize;
-using ::partition_alloc::internal::IterateSlotSpans;
-using ::partition_alloc::internal::PartitionPage;
-using ::partition_alloc::internal::PartitionSuperPageExtentEntry;
-using ::partition_alloc::internal::PartitionSuperPageToExtent;
-using ::partition_alloc::internal::PartitionSuperPageToMetadataArea;
-using ::partition_alloc::internal::ReservedStateBitmapSize;
-using ::partition_alloc::internal::SlotSpanMetadata;
-using ::partition_alloc::internal::StateBitmapFromAddr;
-using ::partition_alloc::internal::SuperPageStateBitmap;
-using ::partition_alloc::internal::SuperPageStateBitmapAddr;
-
-}  // namespace base::internal
-
 #endif  // BASE_ALLOCATOR_PARTITION_ALLOCATOR_PARTITION_PAGE_H_
