@@ -7,6 +7,7 @@
 #include "base/files/file_path.h"
 #include "base/files/file_util.h"
 #include "base/path_service.h"
+#include "build/build_config.h"
 
 namespace base {
 
@@ -19,7 +20,7 @@ bool PathProvider(int key, FilePath* result) {
         return false;
       *result = result->DirName();
       return true;
-#if !defined(OS_FUCHSIA)
+#if !BUILDFLAG(IS_FUCHSIA)
     case DIR_MODULE:
       if (!PathService::Get(FILE_MODULE, result))
         return false;
@@ -27,18 +28,18 @@ bool PathProvider(int key, FilePath* result) {
       return true;
     case DIR_ASSETS:
       return PathService::Get(DIR_MODULE, result);
-#endif  // !defined(OS_FUCHSIA)
+#endif  // !BUILDFLAG(IS_FUCHSIA)
     case DIR_TEMP:
       return GetTempDir(result);
     case DIR_HOME:
       *result = GetHomeDir();
       return true;
     case DIR_GEN_TEST_DATA_ROOT:
-#if !defined(OS_FUCHSIA)
+#if !BUILDFLAG(IS_FUCHSIA)
       // On most platforms, all build output is in the same directory, so
       // use DIR_MODULE to get the path to the current binary.
       return PathService::Get(DIR_MODULE, result);
-#endif  // !defined(OS_FUCHSIA)
+#endif  // !BUILDFLAG(IS_FUCHSIA)
     case DIR_TEST_DATA: {
       FilePath test_data_path;
       if (!PathService::Get(DIR_SRC_TEST_DATA_ROOT, &test_data_path))
