@@ -17,9 +17,9 @@
 #include "base/time/time.h"
 #include "build/build_config.h"
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
 #include "base/win/windows_types.h"
-#elif defined(OS_POSIX) || defined(OS_FUCHSIA)
+#elif BUILDFLAG(IS_POSIX) || BUILDFLAG(IS_FUCHSIA)
 #include <sys/stat.h>
 #include <unistd.h>
 #include <unordered_set>
@@ -58,23 +58,23 @@ class BASE_EXPORT FileEnumerator {
     // On POSIX systems, this is rounded down to the second.
     Time GetLastModifiedTime() const;
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
     // Note that the cAlternateFileName (used to hold the "short" 8.3 name)
     // of the WIN32_FIND_DATA will be empty. Since we don't use short file
     // names, we tell Windows to omit it which speeds up the query slightly.
     const WIN32_FIND_DATA& find_data() const {
       return *ChromeToWindowsType(&find_data_);
     }
-#elif defined(OS_POSIX) || defined(OS_FUCHSIA)
+#elif BUILDFLAG(IS_POSIX) || BUILDFLAG(IS_FUCHSIA)
     const stat_wrapper_t& stat() const { return stat_; }
 #endif
 
    private:
     friend class FileEnumerator;
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
     CHROME_WIN32_FIND_DATA find_data_;
-#elif defined(OS_POSIX) || defined(OS_FUCHSIA)
+#elif BUILDFLAG(IS_POSIX) || BUILDFLAG(IS_FUCHSIA)
     stat_wrapper_t stat_;
     FilePath filename_;
 #endif
@@ -84,7 +84,7 @@ class BASE_EXPORT FileEnumerator {
     FILES = 1 << 0,
     DIRECTORIES = 1 << 1,
     INCLUDE_DOT_DOT = 1 << 2,
-#if defined(OS_POSIX) || defined(OS_FUCHSIA)
+#if BUILDFLAG(IS_POSIX) || BUILDFLAG(IS_FUCHSIA)
     SHOW_SYM_LINKS = 1 << 4,
 #endif
   };
@@ -179,7 +179,7 @@ class BASE_EXPORT FileEnumerator {
 
   bool IsPatternMatched(const FilePath& src) const;
 
-#if defined(OS_WIN)
+#if BUILDFLAG(IS_WIN)
   const WIN32_FIND_DATA& find_data() const {
     return *ChromeToWindowsType(&find_data_);
   }
@@ -188,13 +188,15 @@ class BASE_EXPORT FileEnumerator {
   bool has_find_data_ = false;
   CHROME_WIN32_FIND_DATA find_data_;
   HANDLE find_handle_ = INVALID_HANDLE_VALUE;
-#elif defined(OS_POSIX) || defined(OS_FUCHSIA)
+#elif BUILDFLAG(IS_POSIX) || BUILDFLAG(IS_FUCHSIA)
   // The files in the current directory
   std::vector<FileInfo> directory_entries_;
 
   // Set of visited directories. Used to prevent infinite looping along
   // circular symlinks.
-  std::unordered_set<ino_t> visited_directories_;
+  // The Android NDK (r23) does not declare `st_ino` as an `ino_t`, hence the
+  // need for the ugly decltype.
+  std::unordered_set<decltype(stat_wrapper_t::st_ino)> visited_directories_;
 
   // The next entry to use from the directory_entries_ vector
   size_t current_directory_entry_;
