@@ -6,25 +6,31 @@
 #define BASE_FUCHSIA_SYSTEM_INFO_H_
 
 #include "base/base_export.h"
-#include "base/strings/string_piece_forward.h"
 
-namespace fuchsia {
-namespace buildinfo {
+namespace fuchsia::buildinfo {
 class BuildInfo;
 }
-}  // namespace fuchsia
+namespace fuchsia::hwinfo {
+class ProductInfo;
+}
 
 namespace base {
 
-// Fetches the build info from the system and caches it before returning.
-// Must be called in each process before calling other non-test functions.
+// Makes a blocking call to fetch the info from the system and caches it
+// before returning. Must be called in each process during the initialization
+// phase.
 BASE_EXPORT void FetchAndCacheSystemInfo();
 
 // Returns the cached build info.
 BASE_EXPORT const fuchsia::buildinfo::BuildInfo& GetCachedBuildInfo();
 
-// Reset the cached BuildInfo to empty so that FetchAndCacheSystemInfo()
-// can be called again in this process.
+// Synchronously fetches the system ProductInfo.
+// Returns empty ProductInfo if the required service is unavailable or returns
+// an error.
+BASE_EXPORT fuchsia::hwinfo::ProductInfo GetProductInfo();
+
+// Resets the cached system info to empty so that
+// FetchAndCacheSystemInfo() can be called again in this process.
 BASE_EXPORT void ClearCachedSystemInfoForTesting();
 
 }  // namespace base
