@@ -5,6 +5,7 @@
 #include "base/json/json_parser.h"
 
 #include <cmath>
+#include <iterator>
 #include <utility>
 #include <vector>
 
@@ -52,8 +53,6 @@ std::string ErrorCodeToString(JSONParser::JsonParseError error_code) {
       return JSONParser::kUnsupportedEncoding;
     case JSONParser::JSON_UNQUOTED_DICTIONARY_KEY:
       return JSONParser::kUnquotedDictionaryKey;
-    case JSONParser::JSON_TOO_LARGE:
-      return JSONParser::kInputTooLarge;
     case JSONParser::JSON_UNREPRESENTABLE_NUMBER:
       return JSONParser::kUnrepresentableNumber;
     case JSONParser::JSON_PARSE_ERROR_COUNT:
@@ -64,7 +63,7 @@ std::string ErrorCodeToString(JSONParser::JsonParseError error_code) {
 }
 
 const int32_t kExtendedASCIIStart = 0x80;
-constexpr uint32_t kUnicodeReplacementPoint = 0xFFFD;
+constexpr base_icu::UChar32 kUnicodeReplacementPoint = 0xFFFD;
 
 // UnprefixedHexStringToInt acts like |HexStringToInt|, but enforces that the
 // input consists purely of hex digits. I.e. no "0x" nor "OX" prefix is
@@ -108,7 +107,6 @@ const char JSONParser::kUnsupportedEncoding[] =
     "Unsupported encoding. JSON must be UTF-8.";
 const char JSONParser::kUnquotedDictionaryKey[] =
     "Dictionary keys must be quoted.";
-const char JSONParser::kInputTooLarge[] = "Input string is too large (>2GB).";
 const char JSONParser::kUnrepresentableNumber[] =
     "Number cannot be represented.";
 
@@ -142,19 +140,12 @@ absl::optional<Value> JSONParser::Parse(StringPiece input) {
   // index of the imaginary '\n' immediately before the start of the string:
   // 'A' is in column (0 - -1) = 1.
   line_number_ = 1;
-  index_last_line_ = -1;
+  index_last_line_ = static_cast<size_t>(-1);
 
   error_code_ = JSON_NO_ERROR;
   error_line_ = 0;
   error_column_ = 0;
 
-  // ICU and ReadUnicodeCharacter() use int32_t for lengths, so ensure
-  // that the index_ will not overflow when parsing.
-  if (!base::IsValueInRangeForNumericType<int32_t>(input.length())) {
-    ReportError(JSON_TOO_LARGE, -1);
-    return absl::nullopt;
-  }
-
   // When the input JSON string starts with a UTF-8 Byte-Order-Mark,
   // advance the start position to avoid the ParseNextToken function mis-
   // treating a Unicode BOM as an invalid character and returning NULL.
@@ -203,8 +194,8 @@ JSONParser::StringBuilder::~StringBuilder() = default;
 JSONParser::StringBuilder& JSONParser::StringBuilder::operator=(
     StringBuilder&& other) = default;
 
-void JSONParser::StringBuilder::Append(uint32_t point) {
-  DCHECK(IsValidCodepoint(static_cast<base_icu::UChar32>(point)));
+void JSONParser::StringBuilder::Append(base_icu::UChar32 point) {
+  DCHECK(IsValidCodepoint(point));
 
   if (point < kExtendedASCIIStart && !string_) {
     DCHECK_EQ(static_cast<char>(point), pos_[length_]);
@@ -263,7 +254,7 @@ absl::optional<char> JSONParser::ConsumeChar() {
 }
 
 const char* JSONParser::pos() {
-  CHECK_LE(static_cast<size_t>(index_), input_.length());
+  CHECK_LE(index_, input_.length());
   return input_.data() + index_;
 }
 
@@ -423,7 +414,7 @@ absl::optional<Value> JSONParser::ConsumeDictionary() {
     return absl::nullopt;
   }
 
-  std::vector<Value::DeprecatedDictStorage::value_type> dict_storage;
+  std::vector<std::pair<std::string, Value>> values;
 
   Token token = GetNextToken();
   while (token != T_OBJECT_END) {
@@ -453,7 +444,7 @@ absl::optional<Value> JSONParser::ConsumeDictionary() {
       return absl::nullopt;
     }
 
-    dict_storage.emplace_back(key.DestructiveAsString(), std::move(*value));
+    values.emplace_back(key.DestructiveAsString(), std::move(*value));
 
     token = GetNextToken();
     if (token == T_LIST_SEPARATOR) {
@@ -472,8 +463,9 @@ absl::optional<Value> JSONParser::ConsumeDictionary() {
   ConsumeChar();  // Closing '}'.
   // Reverse |dict_storage| to keep the last of elements with the same key in
   // the input.
-  ranges::reverse(dict_storage);
-  return Value(Value::DeprecatedDictStorage(std::move(dict_storage)));
+  ranges::reverse(values);
+  return Value(Value::Dict(std::make_move_iterator(values.begin()),
+                           std::make_move_iterator(values.end())));
 }
 
 absl::optional<Value> JSONParser::ConsumeList() {
@@ -539,8 +531,7 @@ bool JSONParser::ConsumeStringRaw(StringBuilder* out) {
 
   while (PeekChar()) {
     base_icu::UChar32 next_char = 0;
-    if (!ReadUnicodeCharacter(input_.data(),
-                              static_cast<int32_t>(input_.length()), &index_,
+    if (!ReadUnicodeCharacter(input_.data(), input_.length(), &index_,
                               &next_char) ||
         !IsValidCodepoint(next_char)) {
       if ((options_ & JSON_REPLACE_INVALID_CHARACTERS) == 0) {
@@ -630,7 +621,7 @@ bool JSONParser::ConsumeStringRaw(StringBuilder* out) {
         }
         case 'u': {  // UTF-16 sequence.
           // UTF units are of the form \uXXXX.
-          uint32_t code_point;
+          base_icu::UChar32 code_point;
           if (!DecodeUTF16(&code_point)) {
             ReportError(JSON_INVALID_ESCAPE, -1);
             return false;
@@ -684,7 +675,7 @@ bool JSONParser::ConsumeStringRaw(StringBuilder* out) {
 }
 
 // Entry is at the first X in \uXXXX.
-bool JSONParser::DecodeUTF16(uint32_t* out_code_point) {
+bool JSONParser::DecodeUTF16(base_icu::UChar32* out_code_point) {
   absl::optional<StringPiece> escape_sequence = ConsumeChars(4);
   if (!escape_sequence)
     return false;
@@ -729,7 +720,7 @@ bool JSONParser::DecodeUTF16(uint32_t* out_code_point) {
       return true;
     }
 
-    uint32_t code_point =
+    base_icu::UChar32 code_point =
         CBU16_GET_SUPPLEMENTARY(code_unit16_high, code_unit16_low);
 
     *out_code_point = code_point;
@@ -745,8 +736,8 @@ bool JSONParser::DecodeUTF16(uint32_t* out_code_point) {
 
 absl::optional<Value> JSONParser::ConsumeNumber() {
   const char* num_start = pos();
-  const int start_index = index_;
-  int end_index = start_index;
+  const size_t start_index = index_;
+  size_t end_index = start_index;
 
   if (PeekChar() == '-')
     ConsumeChar();
@@ -785,7 +776,7 @@ absl::optional<Value> JSONParser::ConsumeNumber() {
   // so save off where the parser should be on exit (see Consume invariant at
   // the top of the header), then make sure the next token is one which is
   // valid.
-  int exit_index = index_;
+  size_t exit_index = index_;
 
   switch (GetNextToken()) {
     case T_OBJECT_END:
@@ -861,7 +852,7 @@ bool JSONParser::ConsumeIfMatch(StringPiece match) {
 void JSONParser::ReportError(JsonParseError code, int column_adjust) {
   error_code_ = code;
   error_line_ = line_number_;
-  error_column_ = index_ - index_last_line_ + column_adjust;
+  error_column_ = static_cast<int>(index_ - index_last_line_) + column_adjust;
 
   // For a final blank line ('\n' and then EOF), a negative column_adjust may
   // put us below 1, which doesn't really make sense for 1-based columns.
