@@ -4,12 +4,13 @@
 
 #include "base/logging.h"
 #include <atomic>
+#include <memory>
 
 // logging.h is a widely included header and its size has significant impact on
 // build time. Try not to raise this limit unless absolutely necessary. See
 // https://chromium.googlesource.com/chromium/src/+/HEAD/docs/wmax_tokens.md
 #ifndef NACL_TC_REV
-#pragma clang max_tokens_here 350000
+#pragma clang max_tokens_here 470000
 #endif  // NACL_TC_REV
 
 #ifdef BASE_CHECK_H_
@@ -137,13 +138,33 @@ int g_min_log_level = 0;
 // causing a problem as updates tend to happen early. Atomic ensures there are
 // no problems. To avoid some of the overhead of Atomic, we use
 // |load(std::memory_order_acquire)| and |store(...,
-// std::memory_order_release)| when reading or writing. This
-// guarantees that referenced object is available at the time the point is read.
+// std::memory_order_release)| when reading or writing. This guarantees that the
+// referenced object is available at the time the |g_vlog_info| is read and that
+// |g_vlog_info| is updated atomically.
+//
+// Do not access this directly. You must use |GetVlogInfo|, |InitializeVlogInfo|
+// and/or |ExchangeVlogInfo|.
 std::atomic<VlogInfo*> g_vlog_info = nullptr;
 
+VlogInfo* GetVlogInfo() {
+  return g_vlog_info.load(std::memory_order_acquire);
+}
+
+// Sets g_vlog_info if it is not already set. Checking that it's not already set
+// prevents logging initialization (which can come late in test setup) from
+// overwriting values set via ScopedVmoduleSwitches.
+bool InitializeVlogInfo(VlogInfo* vlog_info) {
+  VlogInfo* previous_vlog_info = nullptr;
+  return g_vlog_info.compare_exchange_strong(previous_vlog_info, vlog_info);
+}
+
+VlogInfo* ExchangeVlogInfo(VlogInfo* vlog_info) {
+  return g_vlog_info.exchange(vlog_info);
+}
+
 // Creates a VlogInfo from the commandline if it has been initialized and if it
 // contains relevant switches, otherwise this returns |nullptr|.
-VlogInfo* VlogInfoFromCommandLine() {
+std::unique_ptr<VlogInfo> VlogInfoFromCommandLine() {
   if (!base::CommandLine::InitializedForCurrentProcess())
     return nullptr;
   base::CommandLine* command_line = base::CommandLine::ForCurrentProcess();
@@ -155,12 +176,46 @@ VlogInfo* VlogInfoFromCommandLine() {
   // See comments on |g_vlog_info|.
   ScopedLeakSanitizerDisabler lsan_disabler;
 #endif  // defined(LEAK_SANITIZER)
-  return new VlogInfo(command_line->GetSwitchValueASCII(switches::kV),
-                      command_line->GetSwitchValueASCII(switches::kVModule),
-                      &g_min_log_level);
+  return std::make_unique<VlogInfo>(
+      command_line->GetSwitchValueASCII(switches::kV),
+      command_line->GetSwitchValueASCII(switches::kVModule), &g_min_log_level);
+}
+
+// If the commandline is initialized for the current process this will
+// initialize g_vlog_info. If there are no VLOG switches, it will initialize it
+// to |nullptr|.
+void MaybeInitializeVlogInfo() {
+  if (base::CommandLine::InitializedForCurrentProcess()) {
+    std::unique_ptr<VlogInfo> vlog_info = VlogInfoFromCommandLine();
+    if (vlog_info) {
+      // VlogInfoFromCommandLine is annotated with ScopedLeakSanitizerDisabler
+      // so it's allowed to leak. If the object was installed, we release it.
+      if (InitializeVlogInfo(vlog_info.get())) {
+        vlog_info.release();
+      }
+    }
+  }
 }
 #endif  // BUILDFLAG(USE_RUNTIME_VLOG)
 
+#if !BUILDFLAG(USE_RUNTIME_VLOG) && DCHECK_IS_ON()
+
+// Warn developers that vlog command line settings are being ignored.
+void MaybeWarnVmodule() {
+  if (base::CommandLine::InitializedForCurrentProcess()) {
+    base::CommandLine* command_line = base::CommandLine::ForCurrentProcess();
+    if (command_line->HasSwitch(switches::kV) ||
+        command_line->HasSwitch(switches::kVModule)) {
+      LOG(WARNING)
+          << "--" << switches::kV << " and --" << switches::kVModule
+          << " are currently ignored. See comments in base/logging.h on "
+             "proper usage of USE_RUNTIME_VLOG.";
+    }
+  }
+}
+
+#endif  // !BUILDFLAG(USE_RUNTIME_VLOG) && DCHECK_IS_ON()
+
 const char* const log_severity_names[] = {"INFO", "WARNING", "ERROR", "FATAL"};
 static_assert(LOGGING_NUM_SEVERITIES == std::size(log_severity_names),
               "Incorrect number of log_severity_names");
@@ -225,8 +280,9 @@ uint64_t TickCount() {
 #if BUILDFLAG(IS_WIN)
   return GetTickCount();
 #elif BUILDFLAG(IS_FUCHSIA)
-  return zx_clock_get_monotonic() /
-         static_cast<zx_time_t>(base::Time::kNanosecondsPerMicrosecond);
+  return static_cast<uint64_t>(
+      zx_clock_get_monotonic() /
+      static_cast<zx_time_t>(base::Time::kNanosecondsPerMicrosecond));
 #elif BUILDFLAG(IS_APPLE)
   return mach_absolute_time();
 #elif BUILDFLAG(IS_NACL)
@@ -237,8 +293,8 @@ uint64_t TickCount() {
   struct timespec ts;
   clock_gettime(CLOCK_MONOTONIC, &ts);
 
-  uint64_t absolute_micro = static_cast<int64_t>(ts.tv_sec) * 1000000 +
-                            static_cast<int64_t>(ts.tv_nsec) / 1000;
+  uint64_t absolute_micro = static_cast<uint64_t>(ts.tv_sec) * 1000000 +
+                            static_cast<uint64_t>(ts.tv_nsec) / 1000;
 
   return absolute_micro;
 #endif
@@ -395,7 +451,7 @@ inline FuchsiaLogSeverity LogSeverityToFuchsiaLogSeverity(
 
 void WriteToFd(int fd, const char* data, size_t length) {
   size_t bytes_written = 0;
-  int rv;
+  long rv;
   while (bytes_written < length) {
     rv = HANDLE_EINTR(write(fd, data + bytes_written, length - bytes_written));
     if (rv < 0) {
@@ -432,11 +488,13 @@ bool BaseInitLoggingImpl(const LoggingSettings& settings) {
 #endif
 
 #if BUILDFLAG(USE_RUNTIME_VLOG)
-  if (base::CommandLine::InitializedForCurrentProcess()) {
-    g_vlog_info.store(VlogInfoFromCommandLine(), std::memory_order_release);
-  }
+  MaybeInitializeVlogInfo();
 #endif  // BUILDFLAG(USE_RUNTIME_VLOG)
 
+#if !BUILDFLAG(USE_RUNTIME_VLOG) && DCHECK_IS_ON()
+  MaybeWarnVmodule();
+#endif  // !BUILDFLAG(USE_RUNTIME_VLOG) && DCHECK_IS_ON()
+
   g_logging_destination = settings.logging_dest;
 
 #if BUILDFLAG(IS_FUCHSIA)
@@ -522,7 +580,7 @@ int GetVlogLevelHelper(const char* file, size_t N) {
 #if BUILDFLAG(USE_RUNTIME_VLOG)
   // Note: |g_vlog_info| may change on a different thread during startup
   // (but will always be valid or nullptr).
-  VlogInfo* vlog_info = g_vlog_info.load(std::memory_order_acquire);
+  VlogInfo* vlog_info = GetVlogInfo();
   return vlog_info ?
       vlog_info->GetVlogLevel(base::StringPiece(file, N - 1)) :
       GetVlogVerbosity();
@@ -604,7 +662,7 @@ LogMessage::LogMessage(const char* file, int line, const char* condition)
 }
 
 LogMessage::~LogMessage() {
-  size_t stack_start = stream_.tellp();
+  size_t stack_start = stream_.str().length();
 #if !defined(OFFICIAL_BUILD) && !BUILDFLAG(IS_NACL) && !defined(__UCLIBC__) && \
     !BUILDFLAG(IS_AIX)
   if (severity_ == LOGGING_FATAL && !base::debug::BeingDebugged()) {
@@ -762,7 +820,7 @@ LogMessage::~LogMessage() {
     // Skip the final character of |str_newline|, since LogMessage() will add
     // a newline.
     const auto message = base::StringPiece(str_newline).substr(message_start_);
-    GetScopedFxLogger().LogMessage(file_, line_,
+    GetScopedFxLogger().LogMessage(file_, static_cast<uint32_t>(line_),
                                    message.substr(0, message.size() - 1),
                                    LogSeverityToFuchsiaLogSeverity(severity_));
 #endif  // BUILDFLAG(IS_FUCHSIA)
@@ -854,6 +912,24 @@ LogMessage::~LogMessage() {
   }
 }
 
+std::string LogMessage::BuildCrashString() const {
+  return BuildCrashString(file(), line(), str().c_str() + message_start_);
+}
+
+std::string LogMessage::BuildCrashString(const char* file,
+                                         int line,
+                                         const char* message_without_prefix) {
+  // Only log last path component.
+  if (file) {
+    const char* slash = strrchr(file, '/');
+    if (slash) {
+      file = slash + 1;
+    }
+  }
+
+  return base::StringPrintf("%s:%d: %s", file, line, message_without_prefix);
+}
+
 // writes the common header info to the stream
 void LogMessage::Init(const char* file, int line) {
   base::StringPiece filename(file);
@@ -1070,7 +1146,7 @@ void RawLog(int level, const char* message) {
     WriteToFd(STDERR_FILENO, message, message_len);
 
     if (message_len > 0 && message[message_len - 1] != '\n') {
-      int rv;
+      long rv;
       do {
         rv = HANDLE_EINTR(write(STDERR_FILENO, "\n", 1));
         if (rv < 0) {
@@ -1106,6 +1182,53 @@ int GetDisableAllVLogLevel() {
 }
 #endif  // !BUILDFLAG(USE_RUNTIME_VLOG)
 
+// Used for testing. Declared in test/scoped_logging_settings.h.
+ScopedVmoduleSwitches::ScopedVmoduleSwitches() = default;
+#if BUILDFLAG(USE_RUNTIME_VLOG)
+VlogInfo* ScopedVmoduleSwitches::CreateVlogInfoWithSwitches(
+    const std::string& vmodule_switch) {
+  // Try get a VlogInfo on which to base this.
+  // First ensure that VLOG has been initialized.
+  MaybeInitializeVlogInfo();
+
+  // Getting this now and setting it later is racy, however if a
+  // ScopedVmoduleSwitches is being used on multiple threads that requires
+  // further coordination and avoids this race.
+  VlogInfo* base_vlog_info = GetVlogInfo();
+  if (!base_vlog_info) {
+    // Base is |nullptr|, so just create it from scratch.
+    return new VlogInfo(/*v_switch_=*/"", vmodule_switch, &g_min_log_level);
+  }
+  return base_vlog_info->WithSwitches(vmodule_switch);
+}
+
+void ScopedVmoduleSwitches::InitWithSwitches(
+    const std::string& vmodule_switch) {
+  // Make sure we are only initialized once.
+  CHECK(!scoped_vlog_info_);
+  {
+#if defined(LEAK_SANITIZER) && !BUILDFLAG(IS_NACL)
+    // See comments on |g_vlog_info|.
+    ScopedLeakSanitizerDisabler lsan_disabler;
+#endif  // defined(LEAK_SANITIZER)
+    scoped_vlog_info_ = CreateVlogInfoWithSwitches(vmodule_switch);
+  }
+  previous_vlog_info_ = ExchangeVlogInfo(scoped_vlog_info_);
+}
+
+ScopedVmoduleSwitches::~ScopedVmoduleSwitches() {
+  VlogInfo* replaced_vlog_info = ExchangeVlogInfo(previous_vlog_info_);
+  // Make sure something didn't replace our scoped VlogInfo while we weren't
+  // looking.
+  CHECK_EQ(replaced_vlog_info, scoped_vlog_info_);
+}
+#else
+void ScopedVmoduleSwitches::InitWithSwitches(
+    const std::string& vmodule_switch) {}
+
+ScopedVmoduleSwitches::~ScopedVmoduleSwitches() = default;
+#endif  // BUILDFLAG(USE_RUNTIME_VLOG)
+
 }  // namespace logging
 
 std::ostream& std::operator<<(std::ostream& out, const wchar_t* wstr) {
